@@ -10,6 +10,7 @@ from urllib.parse import urlparse
 import requests
 import yaml
 
+from tuxrun import __version__
 import tuxrun.templates as templates
 from tuxrun.yaml import yaml_load
 
@@ -59,6 +60,12 @@ DEVICES = [
 ###########
 # Helpers #
 ###########
+def debug(options, msg):
+    if options.debug:
+        for line in msg.split("\n"):
+            print(f"tuxrun: {line}")
+
+
 def download(src, dst):
     url = urlparse(src)
     if url.scheme in ["http", "https"]:
@@ -87,13 +94,24 @@ def pathurlnone(string):
 def setup_parser() -> argparse.ArgumentParser:
     parser = argparse.ArgumentParser(prog="tuxrun", description="TuxRun")
 
+    parser.add_argument(
+        "--version", action="version", version=f"%(prog)s, {__version__}"
+    )
+
     group = parser.add_argument_group("artefacts")
     group.add_argument("--device", default=None, help="Device type", choices=DEVICES)
     group.add_argument("--kernel", default=None, type=pathurlnone, help="kernel URL")
     group.add_argument("--modules", default=None, type=pathurlnone, help="modules URL")
     group.add_argument("--rootfs", default=None, type=pathurlnone, help="rootfs URL")
     group.add_argument("--dtb", default=None, type=pathurlnone, help="dtb URL")
-    group.add_argument("--tests", default="", help="modules URL", choices=["ltp-smoke"])
+    group.add_argument(
+        "--tests",
+        nargs="+",
+        default=[],
+        help="test suites",
+        choices=templates.tests(),
+    )
+    group.add_argument("--boot-args", default="", help="extend boot arguments")
 
     group = parser.add_argument_group("configuration files")
     group.add_argument("--device-dict", default=None, help="Device configuration")
@@ -112,8 +130,15 @@ def setup_parser() -> argparse.ArgumentParser:
         help="Image to use",
     )
 
-    parser.add_argument(
-        "--log-file", default=None, type=Path, help="Store logs to file"
+    group = parser.add_argument_group("logging")
+    group.add_argument("--log-file", default=None, type=Path, help="Store logs to file")
+
+    group = parser.add_argument_group("debugging")
+    group.add_argument(
+        "--debug",
+        default=False,
+        action="store_true",
+        help="Print more debug information about tuxrun",
     )
 
     return parser
@@ -133,10 +158,18 @@ def _main(options, tmpdir: Path) -> int:
             modules=options.modules,
             dtb=options.dtb,
             rootfs=options.rootfs,
-            tests=[t for t in options.tests.split(",") if t],
+            tests=options.tests,
+            timeouts=templates.timeouts(),
+            tux_boot_args=options.boot_args.replace('"', ""),
         )
+        debug(options, "job definition")
+        debug(options, definition)
+
         context = yaml_load(definition).get("context", {})
         device = templates.devices.get_template("qemu.jinja2").render(**context)
+        debug(options, "device dictionary")
+        debug(options, device)
+
         (tmpdir / "definition.yaml").write_text(definition, encoding="utf-8")
         (tmpdir / "device.yaml").write_text(device, encoding="utf-8")
 
@@ -189,6 +222,7 @@ def _main(options, tmpdir: Path) -> int:
         log_file = options.log_file.open("w")
 
     try:
+        debug(options, f"Calling {' '.join(args)}")
         proc = subprocess.Popen(args, bufsize=1, stderr=subprocess.PIPE, text=True)
         assert proc.stderr is not None
         for line in proc.stderr:
@@ -196,9 +230,12 @@ def _main(options, tmpdir: Path) -> int:
             try:
                 data = yaml.load(line, Loader=yaml.CFullLoader)  # type: ignore
                 if not data or not isinstance(data, dict):
+                    debug(options, line)
                     continue
                 if not set(["dt", "lvl", "msg"]).issubset(data.keys()):
+                    debug(options, line)
                     continue
+
                 if log_file is not None:
                     log_file.write("- " + line + "\n")
                 else:
@@ -210,7 +247,7 @@ def _main(options, tmpdir: Path) -> int:
                         f"{COLORS['dt']}{timestamp}{COLORS['end']} {COLORS[level]}{msg}{COLORS['end']}\n"
                     )
             except yaml.YAMLError:
-                pass
+                debug(options, line)
         return proc.wait()
     except FileNotFoundError as exc:
         sys.stderr.write(f"File not found '{exc.filename}'\n")
@@ -279,6 +316,7 @@ def main() -> int:
 
     # Create the temp directory
     tmpdir = Path(tempfile.mkdtemp(prefix="tuxrun-"))
+    debug(options, f"temporary directory: '{tmpdir}'")
     try:
         return _main(options, tmpdir)
     finally:
